@@ -175,6 +175,7 @@ def parse_pbn(file_lines: List[str]) -> List[Event]:
                     board = Board(board_identifier)
                     if not event:
                         event = Event(DEFAULT_EVENT_NAME)
+                    if event not in events:
                         events.append(event)
                     event.boards.append(board)
                     trick_index = 0
@@ -210,18 +211,6 @@ def parse_pbn(file_lines: List[str]) -> List[Event]:
             # Board hands
             elif tag == "Deal":
                 board.hands = _parse_pbn_deal(value)
-                # board.hands_by_seat = {
-                #     'N': board.hands['N'],
-                #     'E': board.hands['E'],
-                #     'S': board.hands['S'],
-                #     'W': board.hands['W'],
-                # }
-                # board.hands_by_index = {
-                #      0: board.hands[0],
-                #      1: board.hands[1],
-                #      2: board.hands[2],
-                #      3: board.hands[3],
-                # }
 
             # Declarer
             elif tag == "Declarer":
@@ -264,7 +253,6 @@ def parse_pbn(file_lines: List[str]) -> List[Event]:
                     # board.tricks[trick_index] = trick
                     board.tricks.append(trick)
                     trick_index += 1
-
     return events
 
 
